@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-01-03 18:09:49 jcs>
+/* Time-stamp: <2005-04-01 23:11:44 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -107,16 +107,16 @@ gboolean pmtm_move_pathlist (GtkTreeView *treeview,
 		tm_list_store_move_after (GTK_LIST_STORE (model),
 					  from_iter, &to_iter);
 	    if (tvt == PLAYLIST_TREEVIEW)
-		gtk_tree_store_move_before (GTK_TREE_STORE (model),
-					    from_iter, &to_iter);
+		pm_list_store_move_after (GTK_LIST_STORE (model),
+					  from_iter, &to_iter);
 	    break;
 	case GTK_TREE_VIEW_DROP_BEFORE:
 	    if (tvt == TRACK_TREEVIEW)
 		tm_list_store_move_before (GTK_LIST_STORE (model),
 					   from_iter, &to_iter);
 	    if (tvt == PLAYLIST_TREEVIEW)
-		gtk_tree_store_move_before (GTK_TREE_STORE (model),
-					    from_iter, &to_iter);
+		pm_list_store_move_before (GTK_LIST_STORE (model),
+					   from_iter, &to_iter);
 	    break;
 	}
     }
