@@ -269,10 +269,10 @@ void pm_remove_all_playlists (gboolean clear_sort)
 /* Select specified playlist */
 void pm_select_playlist (Playlist *playlist)
 {
-    static gboolean pm_select_playlist_fe (GtkTreeModel *model,
-					   GtkTreePath *path,
-					   GtkTreeIter *iter,
-					   gpointer data)
+    gboolean pm_select_playlist_fe (GtkTreeModel *model,
+				    GtkTreePath *path,
+				    GtkTreeIter *iter,
+				    gpointer data)
 	{
 	    Playlist *playlist;
 
@@ -301,10 +301,10 @@ void pm_select_playlist (Playlist *playlist)
 /* Unselect specified playlist */
 void pm_unselect_playlist (Playlist *playlist)
 {
-    static gboolean pm_unselect_playlist_fe (GtkTreeModel *model,
-					     GtkTreePath *path,
-					     GtkTreeIter *iter,
-					     gpointer data)
+    gboolean pm_unselect_playlist_fe (GtkTreeModel *model,
+				      GtkTreePath *path,
+				      GtkTreeIter *iter,
+				      gpointer data)
 	{
 	    Playlist *playlist;
 
