@@ -1,5 +1,5 @@
 /* -*- coding: utf-8; -*-
-|  Time-stamp: <2004-12-11 15:53:39 jcs>
+|  Time-stamp: <2005-03-23 22:00:19 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -1319,6 +1319,7 @@ gchar *get_string_from_template (Track *track,
 	if (*p == '%') {
 	    const gchar* tmp = NULL;
 	    gchar dummy[100];
+	    Playlist *pl;
 	    p++;
 	    switch (*p) {
 	    case 'o':
@@ -1327,6 +1328,11 @@ gchar *get_string_from_template (Track *track,
 		    tmp = basename;
 		}
 		break;
+	    case 'p':
+		pl = pm_get_selected_playlist ();
+		if (pl)
+		    tmp = pl->name;
+		break;
 	    case 'a':
 		tmp = track_get_item_utf8 (track, T_ARTIST);
 		break;
