@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-02-09 00:20:31 jcs>
+/* Time-stamp: <2005-03-22 20:52:09 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -934,15 +934,21 @@ void check_db (void)
 	tokens = g_strsplit(track->ipod_path,":",(track->ipod_path[0]==':'?4:3));
         ntok=ntokens(tokens);
 	if (ntok>=3)
+	{
 	    pathtrack=g_strdup (tokens[ntok-1]);
+	}
 	else
+	{
 	    fprintf(stderr, "Report the bug please: shouldn't be 0 at %s:%d\n",__FILE__,__LINE__);
-        if (localdebug)
+	    pathtrack = NULL;
+	}
+        if (pathtrack && localdebug)
             fprintf(stdout,"File %s\n", pathtrack);
 
 	fflush(stdout);
 
-	g_tree_insert (files_known, pathtrack, track);
+	if (pathtrack)
+	    g_tree_insert (files_known, pathtrack, track);
 	g_strfreev(tokens);
     }
 
